Struct geo_types::line_string::LineString [−][src]
pub struct LineString<T>(pub Vec<Coordinate<T>>)
where
T: CoordinateType;
An ordered collection of two or more Coordinates, representing a
path between locations.
Examples
Create a LineString by calling it directly:
use geo_types::{LineString, Coordinate}; let line_string = LineString(vec![ Coordinate { x: 0., y: 0. }, Coordinate { x: 10., y: 0. }, ]);
Converting a Vec of Coordinate-like things:
use geo_types::LineString; let line_string: LineString<f32> = vec![ (0., 0.), (10., 0.), ].into();
use geo_types::LineString; let line_string: LineString<f64> = vec![ [0., 0.], [10., 0.], ].into();
Or collecting from a Coordinate iterator
use geo_types::{LineString, Coordinate}; let mut coords_iter = vec![ Coordinate { x: 0., y: 0. }, Coordinate { x: 10., y: 0. } ].into_iter(); let line_string: LineString<f32> = coords_iter.collect();
You can iterate over the coordinates in the LineString:
use geo_types::{LineString, Coordinate}; let line_string = LineString(vec![ Coordinate { x: 0., y: 0. }, Coordinate { x: 10., y: 0. }, ]); for coord in line_string { println!("Coordinate x = {}, y = {}", coord.x, coord.y); }
Methods
impl<T: CoordinateType> LineString<T>[src]
impl<T: CoordinateType> LineString<T>ⓘImportant traits for PointsIter<'a, T>pub fn points_iter(&self) -> PointsIter<T>[src]
pub fn points_iter(&self) -> PointsIter<T>pub fn into_points(self) -> Vec<Point<T>>[src]
pub fn into_points(self) -> Vec<Point<T>>pub fn lines<'a>(
&'a self
) -> impl ExactSizeIterator + Iterator<Item = Line<T>> + 'a[src]
pub fn lines<'a>(
&'a self
) -> impl ExactSizeIterator + Iterator<Item = Line<T>> + 'aReturn an Line iterator that yields one Line for each line segment
in the LineString.
Examples
use geo_types::{Line, LineString, Coordinate}; let mut coords = vec![(0., 0.), (5., 0.), (7., 9.)]; let line_string: LineString<f32> = coords.into_iter().collect(); let mut lines = line_string.lines(); assert_eq!( Some(Line::new(Coordinate { x: 0., y: 0. }, Coordinate { x: 5., y: 0. })), lines.next() ); assert_eq!( Some(Line::new(Coordinate { x: 5., y: 0. }, Coordinate { x: 7., y: 9. })), lines.next() ); assert!(lines.next().is_none());
pub fn triangles<'a>(
&'a self
) -> impl ExactSizeIterator + Iterator<Item = Triangle<T>> + 'a[src]
pub fn triangles<'a>(
&'a self
) -> impl ExactSizeIterator + Iterator<Item = Triangle<T>> + 'aTrait Implementations
impl<T: PartialEq> PartialEq for LineString<T> where
T: CoordinateType, [src]
impl<T: PartialEq> PartialEq for LineString<T> where
T: CoordinateType, fn eq(&self, other: &LineString<T>) -> bool[src]
fn eq(&self, other: &LineString<T>) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &LineString<T>) -> bool[src]
fn ne(&self, other: &LineString<T>) -> boolThis method tests for !=.
impl<T: Clone> Clone for LineString<T> where
T: CoordinateType, [src]
impl<T: Clone> Clone for LineString<T> where
T: CoordinateType, fn clone(&self) -> LineString<T>[src]
fn clone(&self) -> LineString<T>Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl<T: Debug> Debug for LineString<T> where
T: CoordinateType, [src]
impl<T: Debug> Debug for LineString<T> where
T: CoordinateType, fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<T: CoordinateType, IC: Into<Coordinate<T>>> From<Vec<IC>> for LineString<T>[src]
impl<T: CoordinateType, IC: Into<Coordinate<T>>> From<Vec<IC>> for LineString<T>Turn a Vec of Point-ish objects into a LineString.
impl<T: CoordinateType, IC: Into<Coordinate<T>>> FromIterator<IC> for LineString<T>[src]
impl<T: CoordinateType, IC: Into<Coordinate<T>>> FromIterator<IC> for LineString<T>Turn a Point-ish iterator into a LineString.
fn from_iter<I: IntoIterator<Item = IC>>(iter: I) -> Self[src]
fn from_iter<I: IntoIterator<Item = IC>>(iter: I) -> SelfCreates a value from an iterator. Read more
impl<T: CoordinateType> IntoIterator for LineString<T>[src]
impl<T: CoordinateType> IntoIterator for LineString<T>Iterate over all the Coordinates in this LineString.
type Item = Coordinate<T>
The type of the elements being iterated over.
type IntoIter = IntoIter<Coordinate<T>>
Which kind of iterator are we turning this into?
fn into_iter(self) -> Self::IntoIter[src]
fn into_iter(self) -> Self::IntoIterCreates an iterator from a value. Read more
impl<T: CoordinateType> From<LineString<T>> for Geometry<T>[src]
impl<T: CoordinateType> From<LineString<T>> for Geometry<T>fn from(x: LineString<T>) -> Geometry<T>[src]
fn from(x: LineString<T>) -> Geometry<T>Performs the conversion.