Struct geo_types::Line [−][src]
pub struct Line<T> where
T: CoordinateType, { pub start: Coordinate<T>, pub end: Coordinate<T>, }
A line segment made up of exactly two Points
Fields
start: Coordinate<T>
end: Coordinate<T>
Methods
impl<T> Line<T> where
T: CoordinateType, [src]
impl<T> Line<T> where
T: CoordinateType, pub fn new<C>(start: C, end: C) -> Line<T> where
C: Into<Coordinate<T>>, [src]
pub fn new<C>(start: C, end: C) -> Line<T> where
C: Into<Coordinate<T>>, Creates a new line segment.
Examples
use geo_types::{Coordinate, Line}; let line = Line::new( Coordinate { x: 0., y: 0. }, Coordinate { x: 1., y: 2. }, ); assert_eq!(line.start, Coordinate { x: 0., y: 0. }); assert_eq!(line.end, Coordinate { x: 1., y: 2. });
pub fn dx(&self) -> T[src]
pub fn dx(&self) -> TCalculate the difference in ‘x’ components (Δx).
Equivalent to:
line.end.x - line.start.x
pub fn dy(&self) -> T[src]
pub fn dy(&self) -> TCalculate the difference in ‘y’ components (Δy).
Equivalent to:
line.end.y - line.start.y
pub fn slope(&self) -> T[src]
pub fn slope(&self) -> TCalculate the slope (Δy/Δx).
Equivalent to:
line.dy() / line.dx()
Note that:
Line::new(a, b).slope() == Line::new(b, a).slope()
pub fn determinant(&self) -> T[src]
pub fn determinant(&self) -> TCalculate the determinant of the line.
Equivalent to:
line.start.x * line.end.y - line.start.y * line.end.x
Note that:
Line::new(a, b).determinant() == -Line::new(b, a).determinant()
pub fn start_point(&self) -> Point<T>[src]
pub fn start_point(&self) -> Point<T>pub fn end_point(&self) -> Point<T>[src]
pub fn end_point(&self) -> Point<T>pub fn points(&self) -> (Point<T>, Point<T>)[src]
pub fn points(&self) -> (Point<T>, Point<T>)Trait Implementations
impl<T: PartialEq> PartialEq for Line<T> where
T: CoordinateType, [src]
impl<T: PartialEq> PartialEq for Line<T> where
T: CoordinateType, fn eq(&self, other: &Line<T>) -> bool[src]
fn eq(&self, other: &Line<T>) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Line<T>) -> bool[src]
fn ne(&self, other: &Line<T>) -> boolThis method tests for !=.
impl<T: Clone> Clone for Line<T> where
T: CoordinateType, [src]
impl<T: Clone> Clone for Line<T> where
T: CoordinateType, fn clone(&self) -> Line<T>[src]
fn clone(&self) -> Line<T>Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl<T: Copy> Copy for Line<T> where
T: CoordinateType, [src]
impl<T: Copy> Copy for Line<T> where
T: CoordinateType, impl<T: Debug> Debug for Line<T> where
T: CoordinateType, [src]
impl<T: Debug> Debug for Line<T> where
T: CoordinateType, fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<T: CoordinateType> From<[(T, T); 2]> for Line<T>[src]
impl<T: CoordinateType> From<[(T, T); 2]> for Line<T>